/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.common.pdfprovider.provider;


import android.graphics.Color;

import com.compdfkit.flutter.compdfkit_flutter.common.utils.ColorUtils;
import com.compdfkit.flutter.compdfkit_flutter.common.views.cpdfviewctrl.CPDFViewCtrl;
import com.compdfkit.ui.reader.CPDFReaderView;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

public class CPDFViewCtrlDataProvider implements CPDFDataProvider {

    private CPDFViewCtrl pdfView;

    public CPDFViewCtrlDataProvider(CPDFViewCtrl pdfView){
        this.pdfView = pdfView;
    }


    @Override
    public void updateConfig(String method, Object arguments) {
        if (pdfView != null){
            CPDFReaderView readerView = pdfView.getCPdfReaderView();
            switch (method) {
                case Method.SET_VERTICAL_MODE:
                    readerView.setVerticalMode(ParamsUtil.getBoolean(arguments, true));
                    break;
                case Method.SET_DOUBLE_PAGE:
                    readerView.setDoublePageMode(ParamsUtil.getBoolean(arguments, false));
                    break;
                case Method.SET_CONTINUE_MODE:
                    readerView.setContinueMode(ParamsUtil.getBoolean(arguments, true));
                    break;
                case Method.SET_COVER_PAGE_MODE:
                    readerView.setCoverPageMode(ParamsUtil.getBoolean(arguments, false));
                    break;
                case Method.SET_CROP_MODE:
                    readerView.setCropMode(ParamsUtil.getBoolean(arguments, false));
                    break;
                case Method.SET_READ_BACKGROUND_COLOR:
                    String hexColor = ParamsUtil.getValue(arguments);
                    readerView.setReadBackgroundColor(Color.parseColor(hexColor));
                    break;
                case Method.SET_DISPLAY_PAGE_INDEX:
                    Map<String, Object> map = ParamsUtil.getValue(arguments);
                    int pageIndex = (int) map.get("pageIndex");
                    boolean animation = (boolean) map.get("animation");
                    readerView.setDisplayPageIndex(pageIndex, animation);
                    break;
                case Method.INVALIDATE_ALL_CHILDREN:
                    readerView.invalidateAllChildren();
                    break;
                default:break;
            }
        }
    }

    @Override
    public void resultConfig(MethodCall call, MethodChannel.Result result) {
        if (pdfView != null){
            CPDFReaderView readerView = pdfView.getCPdfReaderView();
            switch (call.method){
                case Method.IS_VERTICAL_MODE:
                    result.success(readerView.isVerticalMode());
                    break;
                case Method.IS_DOUBLE_PAGE:
                    result.success(readerView.isDoublePageMode());
                    break;
                case Method.IS_CONTINUE_MODE:
                    result.success(readerView.isContinueMode());
                    break;
                case Method.IS_COVER_MODE:
                    result.success(readerView.isCoverPageMode());
                    break;
                case Method.IS_CROP_MODE:
                    result.success(readerView.isCropMode());
                    break;
                case Method.GET_READ_BACKGROUND_COLOR:
                    result.success(ColorUtils.hexColor(readerView.getReadBackgroundColor()));
                    break;
                default:break;
            }
        }
    }



    private static class Method{

        public static final String SET_VERTICAL_MODE = "setVerticalMode";
        public static final String IS_VERTICAL_MODE = "isVerticalMode";

        public static final String SET_DOUBLE_PAGE = "setDoublePage";
        public static final String IS_DOUBLE_PAGE = "isDoublePage";

        public static final String SET_CONTINUE_MODE = "setContinueMode";
        public static final String IS_CONTINUE_MODE = "isContinueMode";

        public static final String SET_CROP_MODE = "setCropMode";
        public static final String IS_CROP_MODE = "isCropMode";

        public static final String SET_COVER_PAGE_MODE = "setCoverPageMode";

        public static final String IS_COVER_MODE = "isCoverPageMode";

        public static final String SET_READ_BACKGROUND_COLOR = "setReadBackgroundColor";
        public static final String GET_READ_BACKGROUND_COLOR = "getReadBackgroundColor";

        public static final String SET_DISPLAY_PAGE_INDEX = "setDisplayPageIndex";

        public static final String INVALIDATE_ALL_CHILDREN = "invalidateAllChildren";
    }
}
