/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.common.pdfprovider.viewer.pdfinfo;


import android.os.ParcelFileDescriptor;
import android.text.TextUtils;

import com.compdfkit.core.document.CPDFDocument;
import com.compdfkit.core.document.CPDFDocumentPermissionInfo;
import com.compdfkit.core.document.CPDFInfo;
import com.compdfkit.tools.common.utils.date.CDateUtil;

import org.json.JSONObject;

import java.text.ParseException;
import java.text.SimpleDateFormat;

public class CPDFInfoDatas {

    public static final String DATE_FORMAT = "yyyy-MM-dd HH:mm:ss";

    public static String getInfo(CPDFDocument document) {
        CPDFInfo info = document.getInfo();
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put("fileName", document.getFileName());
            jsonObject.put("fileSize", getDocumentSize(document));
            jsonObject.put("title", info.getTitle());
            jsonObject.put("author", info.getAuthor());
            jsonObject.put("subject", info.getSubject());
            jsonObject.put("creator", info.getCreator());
            jsonObject.put("producer", info.getProducer());
            jsonObject.put("creationDate", getDocumentDateMill(info.getCreationDate()));
            jsonObject.put("modificationDate", getDocumentDateMill(info.getModificationDate()));
            jsonObject.put("keywords", info.getKeywords());
            jsonObject.put("majorVersion", document.getMajorVersion());
            jsonObject.put("pageCount", document.getPageCount());
        } catch (Exception e) {
            return jsonObject.toString();
        }
        return jsonObject.toString();
    }

    public static String getPermissionsInfo(CPDFDocument document){
        CPDFDocumentPermissionInfo permissionInfo = document.getPermissionsInfo();
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put("allowsPrinting", permissionInfo.isAllowsPrinting());
            jsonObject.put("allowsHighQualityPrinting", permissionInfo.isAllowsHighQualityPrinting());
            jsonObject.put("allowsCopying", permissionInfo.isAllowsCopying());
            jsonObject.put("allowsDocumentChanges", permissionInfo.isAllowsDocumentChanges());
            jsonObject.put("allowsDocumentAssembly", permissionInfo.isAllowsDocumentAssembly());
            jsonObject.put("allowsCommenting", permissionInfo.isAllowsCommenting());
            jsonObject.put("allowsFormFieldEntry", permissionInfo.isAllowsFormFieldEntry());
        } catch (Exception e) {
            return jsonObject.toString();
        }
        return jsonObject.toString();
    }

    private static long getDocumentSize(CPDFDocument document) {
        final long MB = 1024 * 1024;
        final int KB = 1024;
        long fileSize = 0L;
        try {
            ParcelFileDescriptor p = document.getContext().getContentResolver().openFileDescriptor(document.getUri(), "r");
            fileSize = p.getStatSize();
            p.close();
            return fileSize;
        } catch (Exception e) {
            return 0;
        }
    }

    private static long getDocumentDateMill(String date) {
        try {
            String date1 = CDateUtil.transformPDFDate(date);
            if (!TextUtils.isEmpty(date1)) {
                SimpleDateFormat df = new SimpleDateFormat(DATE_FORMAT);
                return df.parse(date1).getTime();
            }
            return 0;
        } catch (Exception e) {
            return 0;
        }
    }

}
