/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.common.pdfprovider.viewer.pdfoutline;

import com.compdfkit.core.document.CPDFDocument;
import com.compdfkit.core.document.CPDFOutline;
import com.compdfkit.tools.viewer.pdfoutline.bean.COutlineData;

import org.json.JSONArray;
import org.json.JSONObject;



public class CPDFOutlineDatas {


    /**
     * Get the list of outlines for a PDF document
     * @param document
     * @see COutlineData
     * @return ArrayList COutlineData
     */
    public static String getOutlineList(CPDFDocument document, int maxLevel) {
        // Retrieve the outline root from the PDF document and convert it to a list of COutlineData objects
        if (document == null) {
            return "";
        }
        CPDFOutline outlineRoot = document.getOutlineRoot();
        JSONArray jsonArray = new JSONArray();
        if (outlineRoot != null) {
            jsonArray =  convertToCOutlineDataList(outlineRoot.getChildList(), maxLevel);
        }
        return jsonArray.toString();
    }

    /**
     * Recursively convert an array of CPDFOutline objects to an ArrayList of COutlineData objects
     * @param outlines outline list data
     */
    private static JSONArray convertToCOutlineDataList(CPDFOutline[] outlines, int maxLevel) {
        try{
            JSONArray jsonArray = new JSONArray();
            for (CPDFOutline outline : outlines) {
                // Convert the CPDFOutline object to a COutlineData object
                JSONObject jsonObject = convertToCOutlineData(outline, maxLevel);
                if (jsonObject != null) {
                    int level = jsonObject.getInt("level");
                    if (level == 1){
                        jsonArray.put(jsonObject);
                    }
                }
                // If the CPDFOutline object has child outlines, convert them to COutlineData objects and add them to the list
                if (outline.getChildList() != null && outline.getChildList().length > 0) {
                    JSONArray child = convertToCOutlineDataList(outline.getChildList(), maxLevel);
                    if (child != null && child.length() >0){
                        jsonArray.put(child);
                    }
                }
            }
            return jsonArray;
        }catch (Exception e){
            return new JSONArray();
        }

    }

    /**
     * Convert a CPDFOutline object to a COutlineData object
     */
    private static JSONObject convertToCOutlineData(CPDFOutline outline, int maxLevel) {
        try{
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("level" , outline.getLevel());
            jsonObject.put("pageIndex", outline.getDestination().getPageIndex());
            jsonObject.put("title", outline.getTitle());
            jsonObject.put("childOutline", new JSONArray());
            // If the CPDFOutline object has child outlines, convert them to COutlineData objects and add them to the list
            if (outline.getChildList() != null && outline.getChildList().length > 0) {
                for (CPDFOutline child : outline.getChildList()) {
                    if (child.getLevel() <= maxLevel) {
                        JSONArray array = jsonObject.getJSONArray("childOutline");
                        array.put(convertToCOutlineData(child, maxLevel));
                    }
                }
            }
            return jsonObject;
        }catch ( Exception e){
            return null;
        }

    }

}
