/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.common.pdfprovider.viewer.pdfsearch;


import com.compdfkit.core.document.CPDFDocument;
import com.compdfkit.core.page.CPDFPage;
import com.compdfkit.core.page.CPDFTextPage;
import com.compdfkit.core.page.CPDFTextRange;
import com.compdfkit.core.page.CPDFTextSearcher;
import com.compdfkit.ui.reader.CPDFReaderView;
import com.compdfkit.ui.textsearch.ITextSearcher;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class CPDFSearchDatas {

    public static String searchKeywordsWithAllPage(CPDFReaderView readerView,
                                                   String keyword,
                                                   int options,
                                                   int resultPrefix,
                                                   int resultSuffix) {
        JSONArray jsonArray = new JSONArray();
        try {
            for (int i = 0; i < readerView.getPDFDocument().getPageCount(); i++) {
                JSONArray items = searchKeywords(readerView, keyword, options, i, resultPrefix, resultSuffix);
                if (items.length() > 0) {
                        jsonArray.put(items.getJSONArray(0));
                }
            }
        } catch (Exception e) {
           return jsonArray.toString();
        }
        return jsonArray.toString();
    }

    public static String searchFirst(CPDFReaderView readerView,
                                                   String keyword,
                                                   int options,
                                                   int resultPrefix,
                                                   int resultSuffix) {
        try {
            for (int i = 0; i < readerView.getPDFDocument().getPageCount(); i++) {
                JSONArray items = searchKeywords(readerView, keyword, options, i, resultPrefix, resultSuffix);
                if (items.length() > 0) {
                    JSONArray jsonArray = items.getJSONArray(0);
                    return  jsonArray.getJSONObject(0).toString();
                }
            }
        } catch (Exception e) {
            return null;
        }
        return null;
    }


    public static JSONArray searchKeywords(CPDFReaderView readerView,
                                           String keyword,
                                           int options,
                                           int pageIndex,
                                           int resultPrefix,
                                           int resultSuffix) {
        JSONArray jsonArray = new JSONArray();
        try {
            if (pageIndex < 0 || pageIndex > readerView.getPDFDocument().getPageCount() - 1) {
                return jsonArray;
            }
            CPDFPage page = readerView.getPDFDocument().pageAtIndex(pageIndex);
            CPDFTextPage textPage = page.getTextPage();
            if (null == textPage || !textPage.isValid()) {
                return jsonArray;
            }
            ITextSearcher textSearcher = readerView.getTextSearcher();
            textSearcher.setSearchConfig(keyword, options);
            List<CPDFTextRange> list = textSearcher.searchKeyword(pageIndex);
            if (list == null || list.size() <= 0) {
                return jsonArray;
            }
            for (int i = 0; i < list.size(); i++) {
                CPDFTextRange textRange = list.get(i);
                JSONObject jsonObject = new JSONObject();
                jsonObject.put("keyword", keyword);
                jsonObject.put("pageIndex", pageIndex);
                int targetStart = textRange.location - resultPrefix;
                int length;
                if (targetStart > 0) {
                    length = textRange.length + resultSuffix + resultPrefix;
                } else {
                    length = textRange.length + (resultSuffix * 2) + targetStart;
                    targetStart = 0;
                }
                CPDFTextRange targetTextRange = new CPDFTextRange(targetStart, length);
                String target = textPage.getText(targetTextRange);
                Pattern p = Pattern.compile(keyword.toLowerCase());
                Matcher m = p.matcher(target.toLowerCase());
                jsonObject.put("text", target);
                jsonObject.put("textRangeIndex", i);
                if (m.find()) {
                    jsonObject.put("textStartIndex", m.start());
                    jsonObject.put("textEndIndex", m.end());
                }
                jsonArray.put(jsonObject);
            }
            page.close();
            JSONArray jsonArray1 = new JSONArray();
            jsonArray1.put(jsonArray);
            return jsonArray1;
        } catch (Exception e) {
            return jsonArray;
        }
    }

}
