/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.common.views.cpdfviewctrl;


import android.content.Context;
import android.text.TextUtils;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.compdfkit.flutter.compdfkit_flutter.common.pdfprovider.provider.CPDFViewCtrlDataProvider;
import com.compdfkit.flutter.compdfkit_flutter.common.utils.task.CExtractAssetFileTask;
import com.compdfkit.flutter.compdfkit_flutter.plugin.CPDFDocumentPlugin;
import com.compdfkit.flutter.compdfkit_flutter.plugin.CPDFViewCtrlPlugin;

import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.platform.PlatformView;

public class CPDFViewCtrlFlutter implements PlatformView {

    public static final String QUICK_START_GUIDE = "Quick Start Guide.pdf";

    private CPDFViewCtrl pdfView;

    private BinaryMessenger binaryMessenger;

    private int viewId;

    public CPDFViewCtrlFlutter(Context context, BinaryMessenger binaryMessenger, int viewId, Map<String, Object> creationParams) {
        this.binaryMessenger = binaryMessenger;
        this.viewId = viewId;
        // Initialize CPDFViewCtrl and initialize related configuration information
        initCPDFViewCtrl(context, creationParams);

    }

    private void initCPDFViewCtrl(Context context, Map<String, Object> creationParams) {
        pdfView = new CPDFViewCtrl(context);
        pdfView.registerPlugin(binaryMessenger, viewId);
        Map<String, Object> configuration = (Map<String, Object>) creationParams.get("configuration");
        CPDFViewCtrlDataProvider provider = new CPDFViewCtrlDataProvider(pdfView);
        for (Map.Entry<String, Object> stringObjectEntry : configuration.entrySet()) {
            provider.updateConfig(stringObjectEntry.getKey(), stringObjectEntry.getValue());
        }
        if (creationParams.get("document") != null) {
            String documentPath = (String) creationParams.get("document");
            if (!TextUtils.isEmpty(documentPath)) {
                pdfView.openPDF(documentPath);
                registerPlugin();

            } else {
                CExtractAssetFileTask.extract(context, QUICK_START_GUIDE, QUICK_START_GUIDE, (filePath) -> {
                            pdfView.openPDF(filePath);
                            registerPlugin();
                        }
                );
            }
        } else {
            CExtractAssetFileTask.extract(context, QUICK_START_GUIDE, QUICK_START_GUIDE, (filePath) -> {
                        pdfView.openPDF(filePath);
                        registerPlugin();
                    }
            );
        }
    }

    private void registerPlugin() {
        new CPDFViewCtrlPlugin(binaryMessenger, viewId, pdfView);
        new CPDFDocumentPlugin(binaryMessenger, viewId, pdfView.getCPdfReaderView());
    }

    @Nullable
    @Override
    public View getView() {
        return pdfView;
    }

    @Override
    public void onFlutterViewAttached(@NonNull View flutterView) {
        PlatformView.super.onFlutterViewAttached(flutterView);
    }

    @Override
    public void onFlutterViewDetached() {
        PlatformView.super.onFlutterViewDetached();
    }

    @Override
    public void dispose() {
        pdfView = null;
    }

    @Override
    public void onInputConnectionLocked() {
        PlatformView.super.onInputConnectionLocked();
    }

    @Override
    public void onInputConnectionUnlocked() {
        PlatformView.super.onInputConnectionUnlocked();
    }
}
