/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.flutter.compdfkit_flutter.plugin;

import android.content.Context;

import androidx.annotation.NonNull;

import com.compdfkit.core.document.CPDFSdk;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;


public class ComPDFKitSDKPlugin extends BaseMethodChannelPlugin {

    public static final String INIT_SDK = "init_sdk";

    public static final String SDK_VERSION_CODE = "sdk_version_code";

    public static final String SDK_BUILD_TAG = "sdk_build_tag";

    public static final String GET_TEMPORARY_DIRECTORY = "getTemporaryDirectory";

    public static final String CREATE_TEST_FILE = "createTestFile";

    private Context context;

    public ComPDFKitSDKPlugin(BinaryMessenger binaryMessenger, Context context) {
        super(binaryMessenger,"com.compdfkit.flutter.plugin");
        this.context = context;
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        switch (call.method) {
            case INIT_SDK:
                result.notImplemented();
                break;
            case SDK_VERSION_CODE:
                result.success(CPDFSdk.getSDKVersion());
                break;
            case SDK_BUILD_TAG:
                result.success(CPDFSdk.getSDKBuildTag());
                break;
            case GET_TEMPORARY_DIRECTORY:
                result.success(context.getCacheDir().getAbsolutePath());
                break;
            default:
                break;
        }
    }
}
