///  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
///
///  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
///  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
///  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
///  This notice may not be removed from this file.

import 'package:flutter/material.dart';

import 'colors.dart';

const lightTextStyle = TextStyle(color: Color(0xFF43474D));
const darkTextStyle = TextStyle(color: Colors.white);

final comPDFKitLightTheme = ThemeData(
    splashColor: const Color(0x334982E6),
    highlightColor: const Color(0x334982E6),
    dividerColor: const Color(0x1A000000),
    scaffoldBackgroundColor: Colors.white,
    colorScheme: const ColorScheme.light(
        primary: Color(0xFF1460F3),
        onPrimary: Colors.black,
        primaryContainer: Color(0xFF1460F3),
        inversePrimary:Colors.white ,
        secondary: Color(0xFF1460F3),
        onSecondary: Colors.white,
        background: Colors.white,
        secondaryContainer: Color(0xFFF2F2F2),
        onBackground: Color(0xFF43474D)),
    tabBarTheme: const TabBarTheme(
      dividerColor: Color(0xFF1460F3),
      labelColor: Color(0xFF1460F3),
      unselectedLabelColor: Color(0xFF43474D),
    ),
    textTheme: TextTheme(
        titleMedium: lightTextStyle.copyWith(fontSize: 16),
        titleLarge: lightTextStyle.copyWith(fontSize: 22),
        titleSmall: lightTextStyle.copyWith(fontSize: 14),
        labelLarge: lightTextStyle.copyWith(fontSize: 14),
        labelMedium: lightTextStyle.copyWith(fontSize: 12),
        labelSmall: lightTextStyle.copyWith(fontSize: 11),
        bodyLarge: lightTextStyle.copyWith(fontSize: 16),
        bodyMedium: lightTextStyle.copyWith(fontSize: 14),
        bodySmall: lightTextStyle.copyWith(fontSize: 12)));

final comPDFKitDarkTheme = ThemeData(
    highlightColor: const Color(0x334982E6),
    splashColor: const Color(0x334982E6),
    dividerColor: const Color(0x1AFFFFFF),
    scaffoldBackgroundColor: const Color(0xFF414347),

    colorScheme: const ColorScheme.dark(
      primary: Color(0xFF6499FF),
      onPrimary: Colors.white,
      primaryContainer: Color(0xFF6499FF),
      inversePrimary:Color(0xCC000000) ,
      secondary: Color(0xFF6499FF),
      onSecondary: Color(0xFF606773),
      background: Color(0xFF414347),
      secondaryContainer: Color(0xFF303238),
    ),
    tabBarTheme: const TabBarTheme(
      dividerColor: Color(0xFF6499FF),
      labelColor: Color(0xFF6499FF),
      unselectedLabelColor: Colors.white,
    ),
    textTheme: TextTheme(
        titleMedium: darkTextStyle.copyWith(fontSize: 16),
        titleLarge: darkTextStyle.copyWith(fontSize: 22),
        titleSmall: darkTextStyle.copyWith(fontSize: 14),
        labelLarge: darkTextStyle.copyWith(fontSize: 14),
        labelMedium: darkTextStyle.copyWith(fontSize: 12),
        labelSmall: darkTextStyle.copyWith(fontSize: 11),
        bodyLarge: darkTextStyle.copyWith(fontSize: 16),
        bodyMedium: darkTextStyle.copyWith(fontSize: 14),
        bodySmall: darkTextStyle.copyWith(fontSize: 12)));

InputDecoration textFieldStyle(BuildContext context) {
  return InputDecoration(
      hintStyle: const TextStyle(fontSize: 14, color: CPDFColors.hintColor),
      focusColor: Theme.of(context).colorScheme.primaryContainer,
      contentPadding: const EdgeInsets.all(2),
      focusedBorder: UnderlineInputBorder(
          borderSide: BorderSide(
              color: Theme.of(context).colorScheme.primaryContainer,
              width: 1.5)));
}
