///
///  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
///
///  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
///  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
///  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
///  This notice may not be removed from this file.

import 'package:flutter/material.dart';

class CPDFRadioListTile extends StatelessWidget {
  final String leadingImageIcon;

  final String leadingPackage;

  final String titleText;

  final bool checked;

  final VoidCallback? onPressed;

  final Color? iconColor;

  const CPDFRadioListTile(
      {Key? key,
      required this.leadingImageIcon,
      this.leadingPackage = '',
      required this.titleText,
      required this.checked,
      this.iconColor,
      this.onPressed})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return _item(context, leadingImageIcon, titleText);
  }

  Widget _item(BuildContext context, String imageIcon, String titleText) {
    return Ink(
        height: 55,
        color: Theme.of(context).colorScheme.background,
        child: InkWell(
          onTap: onPressed,
          child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: 16),
              child: Row(
                children: [
                  Image.asset(imageIcon, package: leadingPackage, color: iconColor),
                  Expanded(
                      child: Padding(
                    padding: const EdgeInsets.only(left: 16),
                    child: Text(titleText,
                        style: Theme.of(context).textTheme.bodyMedium),
                  )),
                  if (checked) ...{
                    Icon(Icons.check,
                        color: Theme.of(context).colorScheme.primaryContainer)
                  }
                ],
              )),
        ));
  }
}
