import 'package:compdfkit_flutter/common/util/Strings.dart';
import 'package:compdfkit_flutter/core/cpdf_view_ctrl.dart';
import 'package:compdfkit_flutter/theme/themes.dart';
import 'package:compdfkit_flutter/widgets/viewer/pdfbota/cpdf_bota_page.dart';
import 'package:compdfkit_flutter/widgets/viewer/pdfdisplaysettings/cpdf_display_settings_page.dart';
import 'package:compdfkit_flutter/widgets/viewer/pdfinfo/cpdf_document_info_page.dart';
import 'package:compdfkit_flutter/widgets/viewer/pdfsearch/cpdf_search_toolbar.dart';
import 'package:flutter/material.dart';

import 'cpdf_action_widget.dart';
import 'cpdf_popup_menu_item.dart';

///  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
///
///  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
///  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
///  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
///  This notice may not be removed from this file.

class CPDFMainToolbar extends StatefulWidget implements PreferredSizeWidget {
  final bool visible;

  final AnimationController? controller;

  final CPDFViewCtrl ctrl;

  bool isDark = false;

  bool showSearchBar = false;

  CPDFMainToolbar(
      {Key? key,
      this.visible = true,
      this.controller,
      this.isDark = false,
      required this.ctrl})
      : super(key: key);

  @override
  State<CPDFMainToolbar> createState() => _CPDFMainToolbarState();

  @override
  Size get preferredSize => const Size(double.infinity, 56);
}

class _CPDFMainToolbarState extends State<CPDFMainToolbar> {
  bool showSearchBar = false;


  @override
  Widget build(BuildContext context) {
    if (widget.controller != null) {
      widget.visible
          ? widget.controller?.reverse()
          : widget.controller?.forward();
      return SlideTransition(
          position: Tween(begin: Offset.zero, end: const Offset(0, -1)).animate(
              CurvedAnimation(
                  parent: widget.controller!, curve: Curves.fastOutSlowIn)),
          child: widget.visible ? _bar() : null);
    } else {
      return _bar();
    }
  }

  Widget _bar() {
    if (showSearchBar) {
      return CPDFSearchToolbar(ctrl: widget.ctrl, isDark: widget.isDark, onBack: (){
        setState(() {
          showSearchBar = false;
          if(!showSearchBar){
            widget.ctrl.document.textSearcher.cancelSearch();
          }
        });
      },);
    } else {
      return _toolbar();
    }
  }

  Widget _toolbar() {
    return Theme(
        data: widget.isDark
            ? comPDFKitDarkTheme
            : comPDFKitLightTheme.copyWith(
                colorScheme: comPDFKitLightTheme.colorScheme
                    .copyWith(primary: const Color(0xFFFAFCFF))),
        child: Builder(builder: (context) {
          return AppBar(
            leading: null,
            title: Row(
              children: [
                InkWell(
                  borderRadius: BorderRadius.circular(6),
                  child: Padding(
                      padding: const EdgeInsets.only(
                          left: 8, right: 8, top: 8, bottom: 8),
                      child: Text('Viewer',
                          style: Theme.of(context)
                              .textTheme
                              .titleLarge
                              ?.copyWith(fontFamily: 'sans-serif-medium'))),
                  onTap: () {},
                ),
              ],
            ),
            titleSpacing: 10,
            elevation: 2,
            actions: actions(),
          );
        }));
  }

  List<Widget> actions() {
    return [
      CPDFActions.thumbnail(onPressed: (context) async {
        pushToBota(
            context, const [CPDFBotaType.thumbnails, CPDFBotaType.outline]);
      }),
      CPDFActions.search(onPressed: (context) {
        setState(() {
          showSearchBar = true;
        });
      }),
      CPDFActions.bota(onPressed: (context) {
        pushToBota(context, const [CPDFBotaType.outline, CPDFBotaType.bookmarks]);
      }),
      Builder(builder: (context) {
        return PopupMenuButton<int>(
          shape: const RoundedRectangleBorder(
              borderRadius: BorderRadius.all(Radius.circular(6))),
          offset: const Offset(0, 56),
          elevation: 2,
          itemBuilder: (context) => [
            const PopupMenuItem(
                value: 1,
                child: CPDFPopUpMenuItem(
                    icon: 'assets/images/ic_view_settings.png',
                    package: 'compdfkit_flutter',
                    title: Strings.ViewSetting)),
            const PopupMenuItem(
                value: 2,
                child: CPDFPopUpMenuItem(
                    icon: 'assets/images/ic_document_info.png',
                    package: 'compdfkit_flutter',
                    title: Strings.DocumentInfo)),
          ],
          onSelected: (value) {
            switch (value) {
              case 1:
                Navigator.push(context, MaterialPageRoute(builder: (_) {
                  return CPDFDisplaySettingsPage(
                    ctrl: widget.ctrl,
                    isDark: widget.isDark,
                  );
                }));
                break;
              case 2:
                Navigator.push(context, MaterialPageRoute(builder: (_) {
                  return CPDFDocumentInfoPage(
                    isDark: widget.isDark,
                    document: widget.ctrl.document,
                  );
                }));
                break;
              default:
                break;
            }
          },
        );
      })
    ];
  }

  void pushToBota(BuildContext context, List<CPDFBotaType> types) async {
    int? pageIndex =
        await Navigator.push(context, MaterialPageRoute(builder: (_) {
      return CPDFBotaPage(
        ctrl: widget.ctrl,
        isDark: widget.isDark,
        types: types,
      );
    }));
    if (pageIndex != null) {
      widget.ctrl.setDisplayPageIndex(pageIndex);
    }
  }
}
